R/RcppExports.R
DR_statistic_time.Rd
Computes the Jetz DR rate, but sample at certain times in the psat
DR_statistic_time(x, sample_times)
an ape::phylo object
a vector of ages
matrix of rates for each tip, by sample time