Computes the interval node statistic, sampling at certain times in the psat

interval_node_statistic(x, sample_times)

Arguments

x

an ape::phylo object

sample_times

a vector of ages

Value

matrix of rates for each tip, by sample time