R/RcppExports.R
interval_node_statistic.Rd
Computes the interval node statistic, sampling at certain times in the psat
interval_node_statistic(x, sample_times)
an ape::phylo object
a vector of ages
matrix of rates for each tip, by sample time